#line 2 "bincfg/bincfg_lex.c"

#line 4 "bincfg/bincfg_lex.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 31
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined __STDC_VERSION__ && __STDC_VERSION__ >= 199901L
#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

#if __STDC__

#define YY_USE_CONST

#endif	/* __STDC__ */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE bc_restart(bc_in  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int bc_leng;

extern FILE *bc_in, *bc_out;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up bc_text. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up bc_text again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

/* The following is because we cannot portably get our hands on size_t
 * (without autoconf's help, which isn't available because we want
 * flex-generated scanners to compile on their own).
 */

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef unsigned int yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via bc_restart()), so that the user can continue scanning by
	 * just pointing bc_in at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when bc_text is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int bc_leng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 1;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow bc_wrap()'s to do buffer switches
 * instead of setting up a fresh bc_in.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void bc_restart (FILE *input_file  );
void bc__switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE bc__create_buffer (FILE *file,int size  );
void bc__delete_buffer (YY_BUFFER_STATE b  );
void bc__flush_buffer (YY_BUFFER_STATE b  );
void bc_push_buffer_state (YY_BUFFER_STATE new_buffer  );
void bc_pop_buffer_state (void );

static void bc_ensure_buffer_stack (void );
static void bc__load_buffer_state (void );
static void bc__init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER bc__flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE bc__scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE bc__scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE bc__scan_bytes (yyconst char *bytes,int len  );

void *bc_alloc (yy_size_t  );
void *bc_realloc (void *,yy_size_t  );
void bc_free (void *  );

#define yy_new_buffer bc__create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        bc_ensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            bc__create_buffer(bc_in,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        bc_ensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            bc__create_buffer(bc_in,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define bc_wrap(n) 1
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

FILE *bc_in = (FILE *) 0, *bc_out = (FILE *) 0;

typedef int yy_state_type;

extern int bc_lineno;

int bc_lineno = 1;

extern char *bc_text;
#define yytext_ptr bc_text

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up bc_text.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	bc_leng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 71
#define YY_END_OF_BUFFER 72
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[215] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   44,   44,   56,   56,   56,   56,
       72,   69,   68,   66,   69,   64,   63,   59,   65,   62,
       70,   70,   60,   17,   15,   16,   18,   67,   59,   60,
       67,   70,   70,   70,   46,   44,   45,   25,   26,   27,
       28,   29,   30,   31,   32,   43,   24,   23,   33,   34,
       35,   36,   37,   38,   39,   40,   41,   42,   55,   56,
       53,   57,   51,   50,   47,   52,   57,   54,   48,   47,
       48,   69,   68,   61,   58,   59,   60,   65,    0,   14,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

       17,   16,   67,   67,   59,   60,    0,    0,    0,    0,
       44,   43,   55,   56,   49,   47,   48,   52,   47,   48,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,   19,   20,   21,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,   22,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    8,    0,    0,
        0,    0,    0,    0,    6,    0,    0,    0,    0,    0,
        5,    0,    0,    0,    0,    0,    0,    0,    0,   12,
        0,    0,    0,    0,    0,    0,   13,    0,    0,    0,

        2,    3,   10,    4,    0,    0,    9,    7,    0,    0,
        0,    1,   11,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    1,    1,    4,    1,    1,    1,    1,
        1,    1,    1,    5,    6,    1,    1,    7,    8,    9,
       10,   11,   12,   13,   14,   15,   15,    1,   16,    1,
       17,    1,    1,   18,   21,   22,   23,   24,   25,   26,
       27,   28,   29,   30,   31,   32,   33,   34,   35,   36,
       37,   38,   39,   40,   41,   42,   43,   37,   44,   37,
       19,    1,   20,    1,    1,    1,   21,   22,   23,   24,

       25,   26,   27,   28,   29,   30,   31,   32,   33,   34,
       35,   36,   37,   38,   39,   40,   41,   42,   43,   37,
       44,   37,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[45] =
    {   0,
        1,    2,    3,    4,    5,    5,    6,    6,    6,    6,
        6,    6,    6,    6,    6,    7,    5,    1,    7,    2,
        8,    8,    8,    8,    8,    8,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5
    } ;

static yyconst flex_int16_t yy_base[231] =
    {   0,
        0,    0,   42,   43,   62,    0,    0,    0,  551,  549,
        9,   10,    0,    0,  106,    0,  150,    0,  194,    0,
      582,  238,  573,  588,  239,  588,    0,  223,    0,  588,
      238,  588,    0,    0,  588,    0,  588,  249,  277,  297,
      567,  547,  220,  530,  588,  562,  588,  588,  588,  588,
      588,  588,  588,  588,  588,    0,  588,  588,  588,  588,
      588,  588,  588,  588,  588,  588,  588,  588,    0,  561,
      588,    0,  588,  588,  306,    0,  588,  588,  326,  321,
        0,  275,  554,  347,    0,  331,    0,    0,  532,  588,
       29,   34,   31,  231,  234,  338,  232,  244,  255,  329,

        0,    0,  365,  544,    0,    0,  520,  507,  503,  499,
      526,    0,    0,  511,    0,    0,    0,    0,  349,    0,
      263,  340,  341,  250,  342,  358,  357,  359,  362,  347,
      364,  368,  484,  588,  588,  588,  369,  371,   36,  373,
      375,  378,  379,  275,  376,  381,  383,  384,  302,  588,
      385,  387,  386,  389,  486,  391,  401,  397,  400,  407,
      402,  484,  408,  411,  412,  416,  419,  588,  482,  418,
      420,  303,  423,  421,  588,  425,  426,  436,  481,  438,
      588,  430,  431,  442,  443,  445,  470,  446,  448,  588,
      450,  469,  468,  465,  463,  452,  588,  451,  462,  348,

      588,  588,  588,  588,  455,  456,  588,  588,  460,  304,
      245,  588,  588,  588,  491,  499,  257,  502,  510,  518,
      521,  529,  537,  545,  553,  561,  564,  572,  575,  578
    } ;

static yyconst flex_int16_t yy_def[231] =
    {   0,
      214,    1,  215,  215,  214,    5,    1,    1,    1,    1,
        1,    1,    1,    1,  214,   15,  214,   17,  214,   19,
      214,  214,  214,  214,  216,  214,  217,  218,  219,  214,
      220,  214,  221,  222,  214,  223,  214,  224,  224,   39,
      224,  214,  214,  214,  214,  214,  214,  214,  214,  214,
      214,  214,  214,  214,  214,  225,  214,  214,  214,  214,
      214,  214,  214,  214,  214,  214,  214,  214,  226,  214,
      214,  227,  214,  214,  226,  228,  214,  214,   75,  229,
      230,  214,  214,  216,  217,  218,  221,  219,  220,  214,
      220,  220,  220,  220,  220,  220,  220,  220,  220,  220,

      222,  223,  224,  224,   39,   40,  214,  214,  214,  214,
      214,  225,  226,  214,  227,   75,   79,  228,  229,  230,
      220,  220,  220,  220,  220,  220,  220,  220,  220,  220,
      220,  220,  214,  214,  214,  214,  220,  220,  220,  220,
      220,  220,  220,  220,  220,  220,  220,  220,  220,  214,
      220,  220,  220,  220,  220,  220,  220,  220,  220,  220,
      220,  220,  220,  220,  220,  220,  220,  214,  220,  220,
      220,  220,  220,  220,  214,  220,  220,  220,  220,  220,
      214,  220,  220,  220,  220,  220,  220,  220,  220,  214,
      220,  220,  220,  220,  220,  220,  214,  220,  220,  220,

      214,  214,  214,  214,  220,  220,  214,  214,  220,  220,
      220,  214,  214,    0,  214,  214,  214,  214,  214,  214,
      214,  214,  214,  214,  214,  214,  214,  214,  214,  214
    } ;

static yyconst flex_int16_t yy_nxt[633] =
    {   0,
       22,   23,   24,   25,   26,   27,   28,   28,   28,   28,
       28,   28,   28,   28,   28,   29,   30,   22,   31,   32,
       33,   33,   33,   33,   33,   33,   32,   32,   32,   32,
       32,   32,   32,   32,   32,   32,   32,   32,   32,   32,
       32,   32,   32,   32,   35,   35,   43,   43,   90,  121,
       90,   44,   44,   90,  122,   90,  153,   36,   36,  123,
       37,   37,   38,   23,   24,   25,   26,   27,   39,   39,
       39,   39,   39,   39,   39,   39,   39,   29,   30,   38,
       31,   32,   40,   40,   40,   40,   40,   40,   41,   41,
       41,   41,   41,   41,   41,   41,   41,   41,   41,   41,

       41,   41,   41,   41,   41,   41,   45,   46,   47,   45,
       45,   45,   48,   49,   50,   51,   52,   53,   54,   55,
       45,   56,   45,   57,   58,   45,   59,   60,   45,   45,
       45,   45,   45,   45,   61,   45,   45,   62,   45,   45,
       63,   64,   45,   65,   45,   66,   45,   67,   68,   45,
       69,   70,   71,   72,   73,   74,   75,   75,   75,   75,
       75,   75,   75,   75,   75,   76,   77,   69,   78,   77,
       79,   79,   79,   79,   79,   79,   69,   69,   69,   69,
       69,   69,   69,   69,   69,   69,   69,   69,   69,   69,
       69,   69,   69,   69,   77,   70,   71,   72,   73,   74,

       80,   80,   80,   80,   80,   80,   80,   80,   80,   76,
       77,   77,   78,   77,   81,   81,   81,   81,   81,   81,
       77,   77,   77,   77,   77,   77,   77,   77,   77,   77,
       77,   77,   77,   77,   77,   77,   77,   77,   82,   82,
      108,   82,   82,   87,   87,   87,   87,   87,   87,  103,
       90,   90,   82,   90,  109,   82,   82,   90,  125,   91,
       92,   93,   85,   90,  213,  124,  103,   94,   95,   90,
       96,   97,  128,   98,   90,   82,   99,  130,   82,  100,
      214,  129,   90,  105,  105,  105,  105,  105,  105,  105,
      105,  105,   82,  140,   90,  158,  137,  106,  106,  106,

      106,  106,  106,  106,  106,  106,  106,  106,  106,  106,
      106,  106,  116,  116,  116,  116,  116,  116,  116,  116,
      116,   90,   90,  212,  163,  184,  117,  117,  117,  117,
      117,  117,  117,  117,  117,  117,  117,  117,  117,  117,
      117,  120,  120,  120,  120,  120,  120,  214,   90,  131,
      214,   87,   87,   87,   87,   87,   87,   90,  126,   90,
       90,   90,  127,  132,  214,  103,   90,  208,   82,  120,
      120,  120,  120,  120,  120,  138,   90,   90,   90,  139,
      142,   90,  103,   90,  147,  141,  146,   90,   90,  144,
       90,  145,   90,  143,   90,   90,  149,   90,   90,  151,

       90,  148,   90,   90,   90,   90,   90,  159,   90,  152,
       90,  154,  160,  155,  157,  156,   90,  161,  165,   90,
       90,   90,  162,  164,  166,  169,   90,   90,  167,  170,
       90,   90,  176,  174,  172,   90,  171,   90,   90,   90,
       90,  173,   90,  185,   90,   90,  178,  180,  179,   90,
       90,  182,  186,  177,  188,   90,  192,   90,  189,  183,
      191,   90,   90,  187,   90,   90,  195,   90,  193,   90,
       90,   90,  194,  206,   90,   90,  196,  209,  199,   90,
      200,  207,  204,  210,  203,  198,  205,  202,  201,  197,
      211,   34,   34,   34,   34,   34,   34,   34,   34,   84,

      190,  181,   84,  175,   84,  168,   84,   86,  150,   86,
       88,   88,  114,   88,   88,   88,   88,   88,   89,   89,
       89,   89,   89,   89,   89,   89,   87,  111,   87,  101,
      101,  136,  101,  101,  101,  135,  101,  102,  102,  134,
      102,  102,  102,  102,  102,  104,  133,  214,  104,  104,
      104,   90,  104,  112,  112,   83,  112,  112,  112,  112,
      112,  113,  114,  111,  110,  113,  113,  107,  113,  115,
      214,  115,  118,  118,   83,  118,  118,  118,  118,  118,
      119,  214,  119,  120,   42,  120,   42,   21,  214,  214,
      214,  214,  214,  214,  214,  214,  214,  214,  214,  214,

      214,  214,  214,  214,  214,  214,  214,  214,  214,  214,
      214,  214,  214,  214,  214,  214,  214,  214,  214,  214,
      214,  214,  214,  214,  214,  214,  214,  214,  214,  214,
      214,  214
    } ;

static yyconst flex_int16_t yy_chk[633] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    3,    4,   11,   12,   91,   91,
       93,   11,   12,   92,   92,  139,  139,    3,    4,   93,
        3,    4,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,

        5,    5,    5,    5,    5,    5,   15,   15,   15,   15,
       15,   15,   15,   15,   15,   15,   15,   15,   15,   15,
       15,   15,   15,   15,   15,   15,   15,   15,   15,   15,
       15,   15,   15,   15,   15,   15,   15,   15,   15,   15,
       15,   15,   15,   15,   15,   15,   15,   15,   15,   15,
       17,   17,   17,   17,   17,   17,   17,   17,   17,   17,
       17,   17,   17,   17,   17,   17,   17,   17,   17,   17,
       17,   17,   17,   17,   17,   17,   17,   17,   17,   17,
       17,   17,   17,   17,   17,   17,   17,   17,   17,   17,
       17,   17,   17,   17,   19,   19,   19,   19,   19,   19,

       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   22,   25,
       43,   22,   25,   28,   28,   28,   28,   28,   28,   38,
       94,   97,   38,   95,   43,   22,   25,   31,   95,   31,
       31,   31,  217,   98,  211,   94,   38,   31,   31,  124,
       31,   31,   97,   31,   99,   82,   31,   99,   82,   31,
       39,   98,  121,   39,   39,   39,   39,   39,   39,   39,
       39,   39,   82,  124,  144,  144,  121,   39,   39,   39,

       39,   39,   39,   40,   40,   40,   40,   40,   40,   40,
       40,   40,   75,   75,   75,   75,   75,   75,   75,   75,
       75,  149,  172,  210,  149,  172,   75,   75,   75,   75,
       75,   75,   79,   79,   79,   79,   79,   79,   79,   79,
       79,   80,   80,   80,   80,   80,   80,   84,  100,  100,
       84,   86,   86,   86,   86,   86,   86,   96,   96,  122,
      123,  125,   96,  100,   84,  103,  130,  200,  103,  119,
      119,  119,  119,  119,  119,  122,  127,  126,  128,  123,
      126,  129,  103,  131,  130,  125,  129,  132,  137,  127,
      138,  128,  140,  126,  141,  145,  132,  142,  143,  137,

      146,  131,  147,  148,  151,  153,  152,  145,  154,  138,
      156,  140,  146,  141,  143,  142,  158,  147,  152,  159,
      157,  161,  148,  151,  153,  156,  160,  163,  154,  157,
      164,  165,  163,  161,  159,  166,  158,  170,  167,  171,
      174,  160,  173,  173,  176,  177,  165,  167,  166,  182,
      183,  170,  174,  164,  177,  178,  182,  180,  178,  171,
      180,  184,  185,  176,  186,  188,  185,  189,  183,  191,
      198,  196,  184,  198,  205,  206,  186,  205,  189,  209,
      191,  199,  195,  206,  194,  188,  196,  193,  192,  187,
      209,  215,  215,  215,  215,  215,  215,  215,  215,  216,

      179,  169,  216,  162,  216,  155,  216,  218,  133,  218,
      219,  219,  114,  219,  219,  219,  219,  219,  220,  220,
      220,  220,  220,  220,  220,  220,  221,  111,  221,  222,
      222,  110,  222,  222,  222,  109,  222,  223,  223,  108,
      223,  223,  223,  223,  223,  224,  107,  104,  224,  224,
      224,   89,  224,  225,  225,   83,  225,  225,  225,  225,
      225,  226,   70,   46,   44,  226,  226,   42,  226,  227,
       41,  227,  228,  228,   23,  228,  228,  228,  228,  228,
      229,   21,  229,  230,   10,  230,    9,  214,  214,  214,
      214,  214,  214,  214,  214,  214,  214,  214,  214,  214,

      214,  214,  214,  214,  214,  214,  214,  214,  214,  214,
      214,  214,  214,  214,  214,  214,  214,  214,  214,  214,
      214,  214,  214,  214,  214,  214,  214,  214,  214,  214,
      214,  214
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int bc__flex_debug;
int bc__flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *bc_text;
#line 1 "bincfg/bincfg_lex.l"
/* Scanner for INTVPC .CFG files */









#line 22 "bincfg/bincfg_lex.l"

/* put any #includes here */
#include "config.h"
#include "bincfg/bincfg.h"
#include "bincfg/bincfg_grmr.tab.h"


#define bc_lex bc_lex1

int  bc_line_no = 1;
int  bc_dec; 
int  bc_hex;
char *bc_txt = NULL;
static int bc_txt_alloc = 0;


#define YYTEXT_TO_BC_TXT \
        do {                                                            \
            if (bc_leng > bc_txt_alloc)                                  \
            {                                                           \
                if (bc_txt)                                             \
                {                                                       \
                    bc_txt_alloc = bc_txt_alloc << 1;                   \
                    free(bc_txt);                                       \
                } else                                                  \
                    bc_txt_alloc = 256;                                 \
                                                                        \
                bc_txt = malloc(bc_txt_alloc);                          \
                                                                        \
                if (!bc_txt)                                            \
                    return TOK_ERROR_OOM;                               \
            }                                                           \
                                                                        \
            strcpy(bc_txt, bc_text);                                     \
        } while (0)



#line 707 "bincfg/bincfg_lex.c"

#define INITIAL 0
#define SEC_IGN 1
#define SEC_VAR 2
#define SEC_BSW 3
#define SEC_MAP 4
#define SEC_ATR 5
#define SEC_PRL 6
#define SEC_MC0 7
#define SEC_MC1 8
#define SEC_MC2 9

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int bc_wrap (void );
#else
extern int bc_wrap (void );
#endif
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO (void) fwrite( bc_text, bc_leng, 1, bc_out )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( bc_in )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( bc_in ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, bc_in))==0 && ferror(bc_in)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(bc_in); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int bc_lex (void);

#define YY_DECL int bc_lex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after bc_text and bc_leng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 65 "bincfg/bincfg_lex.l"

                   
 
/* -------------------------------------------------------------------- */
/*  Rules for identifying section headers.                              */
/* -------------------------------------------------------------------- */
 
#line 873 "bincfg/bincfg_lex.c"

	if ( (yy_init) )
		{
		(yy_init) = 0;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! bc_in )
			bc_in = stdin;

		if ( ! bc_out )
			bc_out = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			bc_ensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				bc__create_buffer(bc_in,YY_BUF_SIZE );
		}

		bc__load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of bc_text. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 215 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 214 );
		yy_cp = (yy_last_accepting_cpos);
		yy_current_state = (yy_last_accepting_state);

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 72 "bincfg/bincfg_lex.l"
{   BEGIN(SEC_BSW); return  TOK_SEC_BANKSWITCH;     }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 73 "bincfg/bincfg_lex.l"
{   BEGIN(SEC_MAP); return  TOK_SEC_MAPPING;        }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 74 "bincfg/bincfg_lex.l"
{   BEGIN(SEC_ATR); return  TOK_SEC_MEMATTR;        }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 75 "bincfg/bincfg_lex.l"
{   BEGIN(SEC_PRL); return  TOK_SEC_PRELOAD;        }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 77 "bincfg/bincfg_lex.l"
{   BEGIN(SEC_MC0); return  TOK_SEC_MACRO;          }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 79 "bincfg/bincfg_lex.l"
{   BEGIN(SEC_VAR); return  TOK_SEC_VARS;           }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 80 "bincfg/bincfg_lex.l"
{   BEGIN(SEC_VAR); return  TOK_SEC_JOYSTICK;       }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 81 "bincfg/bincfg_lex.l"
{   BEGIN(SEC_VAR); return  TOK_SEC_KEYS;           }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 82 "bincfg/bincfg_lex.l"
{   BEGIN(SEC_VAR); return  TOK_SEC_CAPSLOCK;       }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 83 "bincfg/bincfg_lex.l"
{   BEGIN(SEC_VAR); return  TOK_SEC_NUMLOCK;        }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 84 "bincfg/bincfg_lex.l"
{   BEGIN(SEC_VAR); return  TOK_SEC_SCROLLLOCK;     }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 86 "bincfg/bincfg_lex.l"
{   BEGIN(SEC_IGN); return  TOK_SEC_DISASM;         }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 87 "bincfg/bincfg_lex.l"
{   BEGIN(SEC_IGN); return  TOK_SEC_VOICES;         }
	YY_BREAK
case 14:
/* rule 14 can match eol */
YY_RULE_SETUP
#line 89 "bincfg/bincfg_lex.l"
{   BEGIN(SEC_IGN); return  TOK_SEC_UNKNOWN;        }
	YY_BREAK
 
/* -------------------------------------------------------------------- */
/*  Mini-scanner for ignored sections:  Just eat them right up.         */
/* -------------------------------------------------------------------- */

case 15:
/* rule 15 can match eol */
YY_RULE_SETUP
#line 96 "bincfg/bincfg_lex.l"
{   bc_line_no++; /* eat newlines */                }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 97 "bincfg/bincfg_lex.l"
{   /* eat comments */                              }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 98 "bincfg/bincfg_lex.l"
{   /* eat non-section openers. */                  }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 99 "bincfg/bincfg_lex.l"
{   yyless(0);  BEGIN(INITIAL); return '\n';        }
	YY_BREAK
 
/* -------------------------------------------------------------------- */
/*  Keywords that are only valid in memory-attribute section.           */
/* -------------------------------------------------------------------- */

case 19:
YY_RULE_SETUP
#line 106 "bincfg/bincfg_lex.l"
{   return TOK_RAM;                                 }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 107 "bincfg/bincfg_lex.l"
{   return TOK_ROM;                                 }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 108 "bincfg/bincfg_lex.l"
{   return TOK_WOM;                                 }
	YY_BREAK
 
/* -------------------------------------------------------------------- */
/*  Keywords that are only valid in the mapping section.                */
/* -------------------------------------------------------------------- */

case 22:
YY_RULE_SETUP
#line 115 "bincfg/bincfg_lex.l"
{   return TOK_PAGE;                                }
	YY_BREAK
 
/* -------------------------------------------------------------------- */
/*  Keywords that are only valid in the mapping section.                */
/* -------------------------------------------------------------------- */

case 23:
YY_RULE_SETUP
#line 122 "bincfg/bincfg_lex.l"
{   yyless(0); BEGIN(INITIAL);   /*]*/              }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 123 "bincfg/bincfg_lex.l"
{   return TOK_MAC_QUIET;                           }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 124 "bincfg/bincfg_lex.l"
{   BEGIN(SEC_MC2); bc_hex=0; return TOK_MAC_REG;   }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 125 "bincfg/bincfg_lex.l"
{   BEGIN(SEC_MC2); bc_hex=1; return TOK_MAC_REG;   }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 126 "bincfg/bincfg_lex.l"
{   BEGIN(SEC_MC2); bc_hex=2; return TOK_MAC_REG;   }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 127 "bincfg/bincfg_lex.l"
{   BEGIN(SEC_MC1); bc_hex=3; return TOK_MAC_REG;   }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 128 "bincfg/bincfg_lex.l"
{   BEGIN(SEC_MC2); bc_hex=4; return TOK_MAC_REG;   }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 129 "bincfg/bincfg_lex.l"
{   BEGIN(SEC_MC2); bc_hex=5; return TOK_MAC_REG;   }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 130 "bincfg/bincfg_lex.l"
{   BEGIN(SEC_MC2); bc_hex=6; return TOK_MAC_REG;   }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 131 "bincfg/bincfg_lex.l"
{   BEGIN(SEC_MC2); bc_hex=7; return TOK_MAC_REG;   }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 132 "bincfg/bincfg_lex.l"
{   BEGIN(SEC_MC2); return TOK_MAC_AHEAD;           }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 133 "bincfg/bincfg_lex.l"
{   BEGIN(SEC_MC2); return TOK_MAC_BLANK;           }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 134 "bincfg/bincfg_lex.l"
{   BEGIN(SEC_MC2); return TOK_MAC_INSPECT;         }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 135 "bincfg/bincfg_lex.l"
{   BEGIN(SEC_MC1); return TOK_MAC_LOAD;            }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 136 "bincfg/bincfg_lex.l"
{   BEGIN(SEC_MC2); return TOK_MAC_RUNTO;           }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 137 "bincfg/bincfg_lex.l"
{   BEGIN(SEC_MC2); return TOK_MAC_POKE;            }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 138 "bincfg/bincfg_lex.l"
{   BEGIN(SEC_MC2); return TOK_MAC_RUN;             }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 139 "bincfg/bincfg_lex.l"
{   BEGIN(SEC_MC2); return TOK_MAC_TRACE;           }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 140 "bincfg/bincfg_lex.l"
{   BEGIN(SEC_MC2); return TOK_MAC_VIEW;            }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 141 "bincfg/bincfg_lex.l"
{   BEGIN(SEC_MC1); return TOK_MAC_WATCH;           }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 142 "bincfg/bincfg_lex.l"
{   /* ignore comments.       */                    }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 143 "bincfg/bincfg_lex.l"
{   /* ignore whitespace.     */                    }
	YY_BREAK
case 45:
/* rule 45 can match eol */
YY_RULE_SETUP
#line 144 "bincfg/bincfg_lex.l"
{   bc_line_no++; return '\n';                      }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 145 "bincfg/bincfg_lex.l"
{   /* ignore unknown lines.  */                    }
	YY_BREAK
 
/* -------------------------------------------------------------------- */
/*  Special secondary, tertiary states for macro processing.  Grrr...   */
/*  We enter this state after parsing the first 'name' on a line.       */
/*  This keeps hex ranges that aren't $ adorned from turning into       */
/*  TOK_NAMEs.  Too much of the grammar comes into the lexer.  :-P      */
/* -------------------------------------------------------------------- */

case 47:
YY_RULE_SETUP
#line 156 "bincfg/bincfg_lex.l"
{   
                                    BEGIN(SEC_MC2);
                                    bc_dec = atoi(bc_text);
                                    sscanf(bc_text    , "%x", &bc_hex); 
                                    YYTEXT_TO_BC_TXT;
                                    return  TOK_DEC;    
                                }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 163 "bincfg/bincfg_lex.l"
{   
                                    BEGIN(SEC_MC2);
                                    bc_dec = atoi(bc_text);
                                    sscanf(bc_text    , "%x", &bc_hex); 
                                    YYTEXT_TO_BC_TXT;
                                    return  TOK_HEX;    
                                }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 170 "bincfg/bincfg_lex.l"
{   
                                    BEGIN(SEC_MC2);
                                    bc_dec = atoi(bc_text + 1);
                                    sscanf(bc_text + 1, "%x", &bc_hex); 
                                    YYTEXT_TO_BC_TXT;
                                    return  TOK_HEX;    
                                }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 177 "bincfg/bincfg_lex.l"
{   BEGIN(SEC_MC2); return '-';                 }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 178 "bincfg/bincfg_lex.l"
{   BEGIN(SEC_MC2); return ',';                 }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 179 "bincfg/bincfg_lex.l"
{   BEGIN(SEC_MC2); /* eat comments.  */        }
	YY_BREAK
case 53:
/* rule 53 can match eol */
YY_RULE_SETUP
#line 180 "bincfg/bincfg_lex.l"
{   bc_line_no++; BEGIN(SEC_MC0); return '\n';  }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 181 "bincfg/bincfg_lex.l"
{   yyless(0); BEGIN(INITIAL);   /*]*/          }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 183 "bincfg/bincfg_lex.l"
{   
                                    BEGIN(SEC_MC2);
                                    YYTEXT_TO_BC_TXT;                
                                    return  TOK_NAME;   
                                }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 189 "bincfg/bincfg_lex.l"
{ /* ignore whitespace. */                    }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 190 "bincfg/bincfg_lex.l"
{   YYTEXT_TO_BC_TXT; return TOK_ERROR_BAD;     }
	YY_BREAK
 
/* -------------------------------------------------------------------- */
/*  Main scanner with common rules across most sections.                */
/* -------------------------------------------------------------------- */

case 58:
YY_RULE_SETUP
#line 197 "bincfg/bincfg_lex.l"
{   
                bc_dec = atoi(bc_text);
                sscanf(bc_text + 1, "%x", &bc_hex); 
                YYTEXT_TO_BC_TXT;
                return  TOK_DECONLY;    
            }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 203 "bincfg/bincfg_lex.l"
{   
                bc_dec = atoi(bc_text);
                sscanf(bc_text    , "%x", &bc_hex); 
                YYTEXT_TO_BC_TXT;
                return  TOK_DEC;    
            }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 209 "bincfg/bincfg_lex.l"
{   
                bc_dec = atoi(bc_text);
                sscanf(bc_text    , "%x", &bc_hex); 
                YYTEXT_TO_BC_TXT;
                return  TOK_HEX;    
            }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 215 "bincfg/bincfg_lex.l"
{   
                bc_dec = atoi(bc_text + 1);
                sscanf(bc_text + 1, "%x", &bc_hex); 
                YYTEXT_TO_BC_TXT;
                return  TOK_HEX;    
            }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 221 "bincfg/bincfg_lex.l"
{   return '=';                                             }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 222 "bincfg/bincfg_lex.l"
{   return '-';                                             }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 223 "bincfg/bincfg_lex.l"
{   return ',';                                             }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 224 "bincfg/bincfg_lex.l"
{   /* eat comments.  */                                    }
	YY_BREAK
case 66:
/* rule 66 can match eol */
YY_RULE_SETUP
#line 225 "bincfg/bincfg_lex.l"
{   bc_line_no++;
                if (YY_START == SEC_MC1) BEGIN(SEC_MC0);
                return '\n';        /* comments and newlines are same */
            }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 230 "bincfg/bincfg_lex.l"
{   
                YYTEXT_TO_BC_TXT;                
                return  TOK_NAME;   
            }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 235 "bincfg/bincfg_lex.l"
{   /* eat whitespace */                                    }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 236 "bincfg/bincfg_lex.l"
{ YYTEXT_TO_BC_TXT; return TOK_ERROR_BAD;  }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 237 "bincfg/bincfg_lex.l"
{ YYTEXT_TO_BC_TXT; return TOK_ERROR_BAD;  }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 239 "bincfg/bincfg_lex.l"
ECHO;
	YY_BREAK
#line 1393 "bincfg/bincfg_lex.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(SEC_IGN):
case YY_STATE_EOF(SEC_VAR):
case YY_STATE_EOF(SEC_BSW):
case YY_STATE_EOF(SEC_MAP):
case YY_STATE_EOF(SEC_ATR):
case YY_STATE_EOF(SEC_PRL):
case YY_STATE_EOF(SEC_MC0):
case YY_STATE_EOF(SEC_MC1):
case YY_STATE_EOF(SEC_MC2):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed bc_in at a new source and called
			 * bc_lex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = bc_in;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_last_accepting_cpos);
				yy_current_state = (yy_last_accepting_state);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( bc_wrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * bc_text, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of bc_lex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					bc_realloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			bc_restart(bc_in  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 215 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 215 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 214);

	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					bc_restart(bc_in );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( bc_wrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve bc_text */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void bc_restart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        bc_ensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            bc__create_buffer(bc_in,YY_BUF_SIZE );
	}

	bc__init_buffer(YY_CURRENT_BUFFER,input_file );
	bc__load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void bc__switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		bc_pop_buffer_state();
	 *		bc_push_buffer_state(new_buffer);
     */
	bc_ensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	bc__load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (bc_wrap()) processing, but the only time this flag
	 * is looked at is after bc_wrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void bc__load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	bc_in = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE bc__create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) bc_alloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in bc__create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) bc_alloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in bc__create_buffer()" );

	b->yy_is_our_buffer = 1;

	bc__init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with bc__create_buffer()
 * 
 */
    void bc__delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		bc_free((void *) b->yy_ch_buf  );

	bc_free((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a bc_restart() or at EOF.
 */
    static void bc__init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	bc__flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then bc__init_buffer was _probably_
     * called from bc_restart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void bc__flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		bc__load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void bc_push_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	bc_ensure_buffer_stack();

	/* This block is copied from bc__switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from bc__switch_to_buffer. */
	bc__load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void bc_pop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	bc__delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		bc__load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void bc_ensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)bc_alloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)bc_realloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE bc__scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) bc_alloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in bc__scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	bc__switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to bc_lex() will
 * scan from a @e copy of @a str.
 * @param str a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       bc__scan_bytes() instead.
 */
YY_BUFFER_STATE bc__scan_string (yyconst char * yy_str )
{
    
	return bc__scan_bytes(yy_str,strlen(yy_str) );
}

/** Setup the input buffer state to scan the given bytes. The next call to bc_lex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE bc__scan_bytes  (yyconst char * bytes, int  len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = len + 2;
	buf = (char *) bc_alloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in bc__scan_bytes()" );

	for ( i = 0; i < len; ++i )
		buf[i] = bytes[i];

	buf[len] = buf[len+1] = YY_END_OF_BUFFER_CHAR;

	b = bc__scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in bc__scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up bc_text. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		bc_text[bc_leng] = (yy_hold_char); \
		(yy_c_buf_p) = bc_text + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		bc_leng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int bc_get_lineno  (void)
{
        
    return bc_lineno;
}

/** Get the input stream.
 * 
 */
FILE *bc_get_in  (void)
{
        return bc_in;
}

/** Get the output stream.
 * 
 */
FILE *bc_get_out  (void)
{
        return bc_out;
}

/** Get the length of the current token.
 * 
 */
int bc_get_leng  (void)
{
        return bc_leng;
}

/** Get the current token.
 * 
 */

char *bc_get_text  (void)
{
        return bc_text;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void bc_set_lineno (int  line_number )
{
    
    bc_lineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see bc__switch_to_buffer
 */
void bc_set_in (FILE *  in_str )
{
        bc_in = in_str ;
}

void bc_set_out (FILE *  out_str )
{
        bc_out = out_str ;
}

int bc_get_debug  (void)
{
        return bc__flex_debug;
}

void bc_set_debug (int  bdebug )
{
        bc__flex_debug = bdebug ;
}

/* bc_lex_destroy is for both reentrant and non-reentrant scanners. */
int bc_lex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		bc__delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		bc_pop_buffer_state();
	}

	/* Destroy the stack itself. */
	bc_free((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
    	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
    	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *bc_alloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *bc_realloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void bc_free (void * ptr )
{
	free( (char *) ptr );	/* see bc_realloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#undef YY_NEW_FILE
#undef YY_FLUSH_BUFFER
#undef yy_set_bol
#undef yy_new_buffer
#undef yy_set_interactive
#undef yytext_ptr
#undef YY_DO_BEFORE_ACTION

#ifdef YY_DECL_IS_OURS
#undef YY_DECL_IS_OURS
#undef YY_DECL
#endif
#line 239 "bincfg/bincfg_lex.l"



#undef bc_lex

/* We wrap bc_lex with a wrapper that outputs an extra newline at EOF */
int bc_lex(void)
{
    static int need_nl = 1;
    int token = bc_lex1();

    if (token <= 0 && need_nl) 
    { 
        need_nl = 0; 
        return '\n'; 
    }
    if (token > 0) 
    {   
        need_nl = 1; 
    }

    return token;
}

/* ======================================================================== */
/*  This program is free software; you can redistribute it and/or modify    */
/*  it under the terms of the GNU General Public License as published by    */
/*  the Free Software Foundation; either version 2 of the License, or       */
/*  (at your option) any later version.                                     */
/*                                                                          */
/*  This program is distributed in the hope that it will be useful,         */
/*  but WITHOUT ANY WARRANTY; without even the implied warranty of          */
/*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       */
/*  General Public License for more details.                                */
/*                                                                          */
/*  You should have received a copy of the GNU General Public License       */
/*  along with this program; if not, write to the Free Software             */
/*  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.               */
/* ======================================================================== */
/*                 Copyright (c) 2003-+Inf, Joseph Zbiciak                  */
/* ======================================================================== */

